from __future__ import absolute_import
from __future__ import division
from __future__ import print_function
from __future__ import unicode_literals

from io import StringIO

import requests

from . import compat


DEFAULT_CONFIG = {
  'backend': 'https://rawgit.com/dataprotocols/registry/master/registry.csv',
}


def _get_registry_at_endpoint(endpoint):
    '''Return an array of objects from an endpoint that is parsable as CSV'''
    resp = requests.get(endpoint)
    resp.raise_for_status()

    data = StringIO(resp.text)

    reader = compat.csv_dict_reader(data)

    return [o for o in reader]


def get_registry(user_config=None):
    '''Return the DataPackage Registry as an array of objects'''
    config = user_config or DEFAULT_CONFIG

    return _get_registry_at_endpoint(config['backend'])



# -*- coding: utf-8 -*-
from __future__ import absolute_import
from __future__ import division
from __future__ import print_function
from __future__ import unicode_literals

import sys
import csv


_ver = sys.version_info
is_py2 = (_ver[0] == 2)
is_py3 = (_ver[0] == 3)
is_py33 = (is_py3 and _ver[1] == 3)
is_py34 = (is_py3 and _ver[1] == 4)
is_py27 = (is_py2 and _ver[1] == 7)


if is_py2:
    import urlparse as parse
    builtin_str = str
    bytes = str
    str = unicode
    basestring = basestring
    numeric_types = (int, long, float)

    def _iterenc_utf8(data):
        for line in data:
            yield line.encode('utf-8')

    def csv_reader(data, dialect=csv.excel, **kwargs):
        '''Read text stream (unicode on Py2.7) as CSV.'''
        reader = csv.reader(_iterenc_utf8(data), dialect=dialect, **kwargs)
        for row in reader:
            yield [str(cell, 'utf-8') for cell in row]

    def csv_dict_reader(data, dialect=csv.excel, **kwargs):
        '''Read text stream as CSV, yielding dict objects'''
        dict_reader = csv.DictReader(_iterenc_utf8(data), **kwargs)
        for row in dict_reader:
            yield {key: unicode(value, 'utf-8')
                   for key, value in row.iteritems()}

elif is_py3:
    from urllib import parse
    csv_reader = csv.reader
    csv_dict_reader = csv.DictReader
    builtin_str = str
    str = str
    bytes = bytes
    basestring = (str, bytes)
    numeric_types = (int, float)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
from __future__ import absolute_import
from __future__ import division
from __future__ import print_function

import io

from setuptools import setup, find_packages

description = "A Python library for working with a Data Package Registry."
with io.open('README.md') as readme:
    long_description = ''.join(
        filter(lambda x: 'https://travis-ci.org/' not in x,
               readme.readlines()))

setup(
    name='datapackage-registry',
    version='0.0.1',
    url='https://github.com/okfn/datapackage-registry-py',
    license='MIT',
    description=description,
    long_description=long_description,
    maintainer='Brook Elgie',
    maintainer_email='brook.elgie@okfn.org',
    packages=find_packages(exclude=['contrib', 'docs', 'tests*']),
    package_dir={'datapackage_registry': 'datapackage_registry'},
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Utilities',
    ],
    install_requires=[
        'requests>=2.8.0',
    ]
)
